@@ -46,6 +46,20 @@ class TestSerialConnection:
         """Test configuration settings from SerialConnection constructor"""
         assert self.obj.is_settings()
 
+    def test_set_timeout(self):
+        """Test set_timeout method"""
+        assert self.obj.set_timeout(0)
+        assert self.obj.set_timeout(10)
+        assert not self.obj.set_timeout(-1)
+        assert not self.obj.set_timeout("hello")
+
+    def test_set_source_name(self):
+        """Test set_source_name method"""
+        assert self.obj.set_source_name("hello")
+        assert not self.obj.set_source_name("")
+        assert not self.obj.set_source_name(-1)
+        assert not self.obj.set_source_name(None)
+
     def test_get_virtual_ports_paths(self):
         """Test get_virtual_ports_paths method"""
         paths = SerialConnection.get_virtual_ports_paths()
@@ -53,6 +67,7 @@ class TestSerialConnection:
         assert paths[0] == "/tmp"
         assert paths[1] == os.path.expanduser('~')
 
+    # noinspection PyTypeChecker
     def test_get_virtual_home_serial_port(self):
         """Test get_virtual_home_serial_port method"""
         v_ports = [
@@ -67,6 +82,7 @@ class TestSerialConnection:
         tests = [x for x in v_ports if x is not None]
         assert len(tests) == 2
 
+    # noinspection PyTypeChecker
     def test_is_virtual_serial_port(self):
         """Test is_virtual_serial_port method"""
         v_ports = [
@@ -164,6 +180,18 @@ class TestSerialConnection:
         tests = [x for x in timeouts if SerialConnection.is_timeout(x)]
         assert len(tests) == 6
 
+    def test_set_serial_conf(self):
+        """Test set_serial_conf method"""
+        conf = {
+            'serial_port': "/tmp/vmodem0",
+            'baud': 19200,
+            'timeout': 0,
+            'write_timeout': 0,
+            'exclusive': True
+        }
+        result = self.obj.set_serial_conf(**conf)
+        assert Ut.is_dict(result, eq=5)
+
     def test_connect(self):
         """Test connect method"""
         assert self.obj.connect()
