@@ -28,7 +28,7 @@ logger = logging.getLogger("vedirect")
 
 
 class Vedirectsim:
-
+    """Vedirect simulator class."""
     def __init__(self, serialport: str, device: str = "bmv702"):
         self.serialport = serialport
         self.ser = None
@@ -64,6 +64,7 @@ class Vedirectsim:
         return isinstance(self.ser, serial.Serial) and self.ser.is_open
 
     def serial_connect(self) -> bool:
+        """Connect to serial port"""
         self.ser = serial.Serial(self.serialport, 19200, timeout=10)
         self.ser.write_timeout = 2
         if self.is_serial_ready():
@@ -77,19 +78,22 @@ class Vedirectsim:
             self.serialport
         )
 
-    def get_valid_devices(self) -> list:
+    @staticmethod
+    def get_valid_devices() -> list:
         """Get valid devices to simulate vedirect data"""
         return ["bmv702", "bluesolar_1.23", "smartsolar_1.39"]
 
     def set_device(self, device: str):
+        """Set the vedirect device to simulate"""
         self.device = None
-        if Ut.is_str(device) and device in self.get_valid_devices():
+        if Ut.is_str(device) and device in Vedirectsim.get_valid_devices():
             self.device = device
             return True
         return False
 
     def set_dump_file_path(self):
-        if Ut.is_str(self.device) and self.device in self.get_valid_devices():
+        """Set the dump file path to read"""
+        if Ut.is_str(self.device) and self.device in Vedirectsim.get_valid_devices():
             file = "%s.dump" % self.device
             current_path = os.path.dirname(
                 os.path.abspath(
@@ -101,6 +105,7 @@ class Vedirectsim:
         return False
 
     def set_device_settings(self, device: str) -> bool:
+        """Set the device settings"""
         if self.set_device(device)\
                 and self.set_dump_file_path():
             logger.info(
@@ -115,6 +120,7 @@ class Vedirectsim:
         )
 
     def process_data(self, data: str):
+        """Process read data"""
         if Ut.is_str(data):
             value = data.replace('\n', "").replace('\r', "")
             res = value.split('\t')
@@ -128,6 +134,7 @@ class Vedirectsim:
                     self.send_packet()
 
     def read_dump_file_lines(self, max_writes: int or None = None) -> bool:
+        """Read file lines"""
         if self.is_ready():
             logger.info(
                 "Starting to read dump file lines on device %s. " 
@@ -153,6 +160,7 @@ class Vedirectsim:
         return False
 
     def convert(self, data: dict) -> list:
+        """Convert data to vedirect protocol"""
         result = list()
         for key in self.dict:
             result.append(ord('\r'))
@@ -169,6 +177,7 @@ class Vedirectsim:
         return result
                       
     def send_packet(self):
+        """Send the packet to serial port"""
         start = time.time()
         packet = self.convert(self.dict)
         try:
@@ -193,6 +202,7 @@ class Vedirectsim:
             time.sleep(sleep_time)
         
     def run(self, max_writes: int or None = None) -> bool:
+        """Run the simulator"""
         if self.is_ready():
             running = True
             while running:
